@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Representer;
 
-our $VERSION = '0.010_001'; # TRIAL VERSION
+our $VERSION = '0.010_002'; # TRIAL VERSION
 
 use Scalar::Util qw/ reftype blessed refaddr /;
 
@@ -98,7 +98,7 @@ sub dump_node {
     if (ref $value) {
 
         my $refaddr = refaddr $value;
-        if ($seen->{ $refaddr } > 1) {
+        if ($seen->{ $refaddr } and $seen->{ $refaddr } > 1) {
             $anchor = $self->{refs}->{ $refaddr };
             unless (defined $anchor) {
                 my $num = ++$self->{anchor_num};
@@ -202,6 +202,11 @@ sub dump_node {
         my $type = $code->($self, $node);
         $done = 1 if $type;
     }
+    if (not $done and $node->{reftype} eq 'REF' and my $refref = $representers->{refref}) {
+        my $code = $refref->{code};
+        my $type = $code->($self, $node);
+        $done = 1 if $type;
+    }
     if (not $done and $node->{reftype} eq 'CODE' and my $coderef = $representers->{coderef}) {
         my $code = $coderef->{code};
         my $type = $code->($self, $node);
@@ -305,6 +310,8 @@ sub check_references {
             }
             elsif (reftype($doc) eq 'SCALAR') {
             }
+            elsif (reftype($doc) eq 'REF') {
+            }
             else {
                 die "Reference @{[ ref $doc ]} not implemented";
             }
