@@ -3,7 +3,7 @@ use warnings;
 package YAML::PP::Schema;
 use B;
 
-our $VERSION = '0.010_001'; # TRIAL VERSION
+our $VERSION = '0.010_002'; # TRIAL VERSION
 
 use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE /;
 
@@ -140,6 +140,12 @@ sub add_representer {
         };
         return;
     }
+    if (defined(my $refref = $args{refref})) {
+        $representers->{refref} = {
+            code => $args{code},
+        };
+        return;
+    }
     if (defined(my $coderef = $args{coderef})) {
         $representers->{coderef} = {
             code => $args{code},
