@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Schema::Perl;
 
-our $VERSION = '0.010_001'; # TRIAL VERSION
+our $VERSION = '0.010_002'; # TRIAL VERSION
 
 use base 'YAML::PP::Schema';
 
@@ -39,6 +39,17 @@ sub register {
             %{ $node->{data} } = ( '=' => ${ $node->{value} } );
         },
     );
+    $schema->add_representer(
+        refref => 1,
+        code => sub {
+            my ($rep, $node) = @_;
+            $node->{tag} = PREFIX_PERL . "ref";
+            if (blessed($node->{value})) {
+                $node->{tag} .= ':' . blessed($node->{value});
+            }
+            %{ $node->{data} } = ( '=' => ${ $node->{value} } );
+        },
+    );
     $schema->add_representer(
         coderef => 1,
         code => sub {
@@ -95,6 +106,9 @@ sub register {
                     %{ $node->{data} } = ( '=' => ${ $node->{value} } );
                 }
             }
+            elsif ($node->{reftype} eq 'REF') {
+                %{ $node->{data} } = ( '=' => ${ $node->{value} } );
+            }
 
             elsif ($node->{reftype} eq 'CODE') {
                 require B::Deparse;
@@ -234,6 +248,34 @@ YAML:
         U: 2
 
 
+=item refref
+
+        # Code
+        my $ref = { a => 'hash' };
+        my $refref = \$ref;
+        $refref;
+
+
+        # YAML
+        --- !perl/ref
+        =:
+          a: hash
+
+
+=item refref_blessed
+
+        # Code
+        my $ref = { a => 'hash' };
+        my $refref = bless \$ref, 'Foo';
+        $refref;
+
+
+        # YAML
+        --- !perl/ref:Foo
+        =:
+          a: hash
+
+
 =item regexp
 
         # Code
